# Step 4: Evaluate Data
### On this page
  * [Before You Start](https://help.sap.com/docs/leanix/ea/application-rationalization-evaluate-data#before-you-start)
  * [Evaluate by Gartner TIME Framework](https://help.sap.com/docs/leanix/ea/application-rationalization-evaluate-data#evaluate-by-gartner-time-framework)
  * [Prioritize with Reports](https://help.sap.com/docs/leanix/ea/application-rationalization-evaluate-data#prioritize-with-reports)
  * [Record Rationalization Decisions](https://help.sap.com/docs/leanix/ea/application-rationalization-evaluate-data#record-rationalization-decisions)
  * [Related Resources](https://help.sap.com/docs/leanix/ea/application-rationalization-evaluate-data#related-resources)


Leverage automated TIME classification, application portfolio and landscape reports, and collaborative decision tools to streamline application rationalization and visualize cost-saving opportunities
rationalization has been prepared in the previous steps. Now you evaluate the application data and discover opportunities to streamline the application portfolio. There are different evaluation methodologies. A common approach is using the Gartner TIME framework.
